Django PayPal
=============

.. image:: https://travis-ci.org/spookylukey/django-paypal.svg?branch=master
    :target: https://travis-ci.org/spookylukey/django-paypal
    :alt: Build Status

.. image:: https://pypip.in/v/django-paypal/badge.png
    :target: https://pypi.python.org/pypi/django-paypal
    :alt: Latest PyPI version

Django PayPal is a pluggable application that integrates with PayPal Payments
Standard and Payments Pro.

See https://django-paypal.readthedocs.org/ for documentation.

django-paypal supports Python 2.7, 3.3 and 3.4, and Django from version 1.4 to 1.7.

Please read the docs if you are upgrading from Django 1.7
